.. :changelog:

History
-------

0.9.0.10(2025-08-25)
---------------------

* Support UCS Central release 2.1(1c)



0.9.0.9(2025-05-15)
---------------------

* Support UCS Central release 2.1(1a)



0.9.0.8(2024-09-20)
---------------------

* Support UCS Central release 2.0(1v)



0.9.0.7(2024-06-05)
---------------------

* Defect fix for UCS Central release 2.0(1u)



0.9.0.6(2024-05-30)
---------------------

* Defect fix for UCS Central release 2.0(1u)



0.9.0.5(2024-04-30)
---------------------

* Support UCS Central release 2.0(1u)



0.9.0.4(2023-11-06)
---------------------

* Support UCS Central release 2.0(1t), 2.0(1s)



0.9.0.3(2022-08-17)
---------------------

* Bug fixes



0.9.0.2(2021-11-11)
---------------------

* Support UCS Central release 2.0(1m), 2.0(1o)


0.9.0.1 (2018-04-26)
---------------------

* Support UCS Central release 2.0(1d)
* Adding test infra with parameters from config file to be used for sanity
* Fix for the issue where None values are compared for validation of property


0.9.0.0 (2016-11-14)
---------------------

* Python SDK for UCS Central management and related automation
* Supports every Managed Object exposed by UCS Central
* APIs for CRUD operations
* Support for UCS Central and domain backup, export/import configuration
* Support for firmware management and tech-support
* Support for UCS Domain management
* Support for server side filters
* Support for UCS Central eventhandlers
* Logging support
* Nosetests for unit testing
* Integrating the sphinx framework for documentation
* PEP8 Compliance
